# LLM Document Analysis

A Python library for LLM-powered document analysis and processing. This library provides a flexible and extensible framework for analyzing documents using Large Language Models.

## Features

- Document processing for various formats (PDF, Text, etc.)
- Integration with popular LLM providers
- Extensible processor architecture
- Built-in logging and error handling
- Async support for better performance

## Installation

You can install the package directly from PyPI:

```bash
pip install llm-document-analysis
```

For development installation with additional tools:

```bash
pip install llm-document-analysis[dev]
```

## Quick Start

```python
from llm_document_analysis import DocumentAnalyzer
from llm_document_analysis.processors import PDFProcessor

# Initialize the analyzer
analyzer = DocumentAnalyzer()

# Process a PDF document
processor = PDFProcessor("path/to/document.pdf")
result = analyzer.analyze(processor)

# Access the analysis results
print(result.summary)
print(result.key_points)
```

## Development

1. Clone the repository:
```bash
git clone https://github.com/Venere-Labs/llm-document-analysis.git
cd llm-document-analysis
```

2. Create a virtual environment:
```bash
python -m venv .venv
source .venv/bin/activate  # On Windows: .venv\Scripts\activate
```

3. Install development dependencies:
```bash
pip install -e ".[dev]"
```

4. Run tests:
```bash
pytest
```

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Support

If you encounter any problems or have questions, please [open an issue](https://github.com/Venere-Labs/llm-document-analysis/issues) on GitHub. 